@@ -25,4 +25,6 @@ from .param import CLASS_TO_POS_TAG, PUNCTUATION, SYMBOLS, SUBSTANTIVE_PLACEHOLD
     NUMERIC_PLACEHOLDERS, OOV_TOKEN, FILE_NAME_DIVIDERS, \
     SET_WORDS, PREPOSITION_ARTICLES, OBLIQUE_PERSONAL_PRONOUN, VERB_EXCEPTIONS, ADDRESS
 
-from .utils import get_class_name_from_file
+from .abbreviations import ABBREVIATIONS
+
+from .utils import get_class_name_from_file, replace_abbreviations
